vxml_pipeline/desugarers/absorb_backward_one

Values

pub fn constructor(param: #(String, String)) -> core.Desugarer

Moves each element of the absorbed tag into the start of the immediately following element of the absorber tag.

pub const name: String
Search Document