vxml_pipeline/desugarers/absorb_forward_one

Values

pub fn constructor(param: #(String, String)) -> core.Desugarer

Moves each element of the absorbed tag into the end of the immediately preceding element of the absorber tag.

pub const name: String
Search Document