vxml_pipeline/desugarers/absorb_into_previous_sibling

Values

pub fn constructor(param: List(String)) -> core.Desugarer

Moves each uninterrupted run of elements of the specified tags into the end of its preceding element when that element’s tag is not specified.

pub const name: String
Search Document