vxml_pipeline/desugarers/add_before_but_not_before_first_child

Values

pub fn constructor(param: #(String, String)) -> core.Desugarer

Inserts an empty element of the specified tag immediately before each target element, except when the target is its parent’s first child.

pub const name: String
Search Document