vxml_pipeline/desugarers/add_before_but_not_before_first_child__batch
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: List(#(String, String)),
) -> core.Desugarer
Inserts each configured empty element immediately before its target elements, except when a target is its parent’s first child.