vxml_pipeline/desugarers/add_before_but_not_before_first_of_kind__batch

Values

pub fn constructor(
  param: List(#(String, String, List(#(String, String)))),
) -> core.Desugarer

Inserts each configured element with attributes immediately before every matching element after its first occurrence among the same parent’s children.

pub const name: String
Search Document