vxml_pipeline/desugarers/add_class_to_next_sibling
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: #(String, String)) -> core.Desugarer
For each marker element, adds the requested class to its immediately following sibling and removes the marker.