vxml_pipeline/desugarers/append
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(String, String, core.TrafficLight),
) -> core.Desugarer
Appends an element to every matching element, optionally returning early from each matched subtree according to the traffic-light argument.