vxml_pipeline/desugarers/append_attribute__outside

Values

pub fn constructor(
  param: #(String, String, String),
  outside: List(String),
) -> core.Desugarer

Appends an attribute to matching elements outside the forbidden subtrees, returning from each subtree once the attribute has been added.

pub const name: String
Search Document