vxml_pipeline/desugarers/append_attribute_if_child_of

Values

pub fn constructor(
  param: #(String, String, String, String),
) -> core.Desugarer

Appends an attribute to matching children of a specified parent without replacing an existing attribute of the same key.

pub const name: String
Search Document