vxml_pipeline/desugarers/append_attribute_if_child_of__batch

Values

pub fn constructor(
  param: List(#(String, String, String, String)),
) -> core.Desugarer

Appends configured attributes to matching children of specified parents without replacing existing attributes of the same keys.

pub const name: String
Search Document