vxml_pipeline/desugarers/auto_generate_child_if_missing_from_attribute__outside
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(String, String, String),
outside: List(String),
) -> core.Desugarer
Prepends a child populated from an attribute outside forbidden subtrees when a matching parent has the attribute but no child of the requested tag.