vxml_pipeline/desugarers/delete__batch
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: List(String)) -> core.Desugarer
Removes every element whose tag is in the supplied list.
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: List(String)) -> core.Desugarer
Removes every element whose tag is in the supplied list.