vxml_pipeline/desugarers/delete_empty_lines
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor() -> core.Desugarer
Removes empty lines and removes text nodes left without any lines.
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor() -> core.Desugarer
Removes empty lines and removes text nodes left without any lines.