vxml_pipeline/desugarers/expand_emmet_like_attribute

Values

pub fn constructor(
  param: #(List(String), List(String), String),
) -> core.Desugarer

Expands an Emmet-like shorthand attribute into a leading value attribute plus HTML id, class, and style attrs. At most one of the configured shorthand keys may be present.

pub const name: String
Search Document