vxml_pipeline/desugarers/handles_add_ids

Values

pub fn constructor() -> core.Desugarer

For each node that has an attr of key ‘handle’:

  1. generates a unique id attr added to the node, if not already present

  2. parses each ‘handle’ attr value in the form

handle=handle_name <<handle_value>>

and replaces this key-value pair with

handle=handle_name <<handle_value>>

The id is stored only in the element’s sibling id= attribute. The value envelope preserves boundary whitespace.

pub const name: String
Search Document