vxml_pipeline/desugarers/insert_custom_before_first
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(String, vxml.VXML, String, core.TrafficLight),
) -> core.Desugarer
For a given tag, adds a custom child to all nodes of that tag at the first position right before tags of another given string, or else as the last child if no such other tag is found.
Early-returns after operating on a node depending on the value of the last argument.