vxml_pipeline/desugarers/nuke_ancestors
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: String) -> core.Desugarer
Removes every ancestor of each element with the configured tag.
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: String) -> core.Desugarer
Removes every ancestor of each element with the configured tag.