vxml_pipeline/desugarers/prepend_attribute__batch
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: List(#(String, String, String)),
) -> core.Desugarer
Prepends each configured attribute to every element of its configured tag. Repeated target tags are allowed and receive every associated attribute in list order.