vxml_pipeline/desugarers/source_provenance_append_img_spans
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(
String,
String,
List(String),
List(#(String, String)),
List(#(String, String)),
),
) -> core.Desugarer
Appends configured sibling spans containing image source paths, including an optional path inherited from an ancestor attribute.