vxml_pipeline/desugarers/trim
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: String) -> core.Desugarer
Trims boundary whitespace from elements with the configured tag.
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: String) -> core.Desugarer
Trims boundary whitespace from elements with the configured tag.