vxml_pipeline/desugarers/trim_ending_spaces_except_last_line
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor() -> core.Desugarer
Trims ending spaces from every text line except the last.
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor() -> core.Desugarer
Trims ending spaces from every text line except the last.