vxml_pipeline/desugarers/unwrap
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: String) -> core.Desugarer
Replaces elements with the configured tag by their children.
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(param: String) -> core.Desugarer
Replaces elements with the configured tag by their children.