vxml_pipeline/desugarers/add_after_but_not_after_last_child__batch

Values

pub fn constructor(
  param: List(#(String, String, List(#(String, String)))),
) -> core.Desugarer

Inserts the configured element with attributes after each matching element, except when the matching element is its parent’s last child.

pub const name: String
Search Document