vxml_pipeline/desugarers/add_before_but_not_before_first_of_kind

Values

pub fn constructor(param: #(String, String)) -> core.Desugarer

Inserts an empty element of the specified tag immediately before every target element after the first target among the same parent’s children.

pub const name: String
Search Document