vxml_pipeline/desugarers/add_between

Values

pub fn constructor(
  param: #(String, String, String),
) -> core.Desugarer

Inserts an empty element of the specified tag between each adjacent pair whose first and second elements have the configured tags.

pub const name: String
Search Document