vxml_pipeline/desugarers/add_between_all_pairs_2
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(List(String), List(String), String),
) -> core.Desugarer
Inserts an empty element between adjacent element siblings when the left tag is in the first list and the right tag is in the second; for efficiency, use the smaller tag list as the second list.