vxml_pipeline/desugarers/append_class_to_child_if_is_not_one_of
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(String, String, List(String)),
) -> core.Desugarer
Appends a class to children of a specified parent when their tag is not among the specified tags.