vxml_pipeline/desugarers/append_class_to_child_if_is_one_of

Values

pub fn constructor(
  param: #(String, String, List(String)),
) -> core.Desugarer

Appends a class to children of a specified parent when their tag is among the specified tags.

pub const name: String
Search Document