vxml_pipeline/desugarers/auto_generate_child_if_missing_from_attribute
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(String, String, String),
) -> core.Desugarer
Prepends a child populated from an attribute when a matching parent has the attribute but no child of the requested tag.