vxml_pipeline/desugarers/auto_generate_child_if_missing_from_attribute__batch
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: List(#(String, String, String)),
) -> core.Desugarer
Prepends children populated from attributes when matching parents have the configured attribute but no child of the requested tag. Repeated parent tags are allowed.