vxml_pipeline/desugarers/handles_add_ids
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor() -> core.Desugarer
Adds a unique id attr to each element carrying an
exact handle attr, unless the element already has an id.
The handle value is left untouched.