vxml_pipeline/desugarers/handles_add_ids

Values

pub fn constructor() -> core.Desugarer

For each node that has an attr of key ‘handle’:

  1. generates a unique id attr added to the node, if not already present

  2. parses each ‘handle’ attr value in the form

handle=handle_name [handle_value]

where the handle_value string is an optional string separated from handle_name that may or may not be present, and replaces this key-value pair with

handle=handle_name|handle_value|id

while using the empty string for ‘handle_value’, if not present

pub const name: String
Search Document