vxml_pipeline/desugarers/handles_generate_v_definitions_from_t_definitions

Values

pub fn constructor() -> core.Desugarer

Scans every text node (T) for in-text handle definitions of the form

PRECEDING_CHAR handleName[#decorator…]##<<VALUE

where PRECEDING_CHAR is the start of the line, a space, ‘#’, ‘(’ or ‘[’; handleName must satisfy the handle-name regex; each #decorator consists of ‘#’ followed by one or more decorator chars; and VALUE is everything after ‘##<<’ up to the first un-bracketed space or ‘|’, end of string, or unmatched closing bracket.

For each match found, the desugarer:

  1. Replaces the matched span with just PRECEDING_CHAR + VALUE in the text, except that a ‘#’ preceding char is removed.
  2. Adds a ‘handle=handleName VALUE’ attribute to the closest ancestor V node of the T node.

If ‘##<<’ is found but what precedes it does not form a valid handle-name pattern (or has no valid preceding char), that occurrence is left untouched with no error or warning.

Intended to run before handles_add_ids so that the generated ‘handle=’ attrs are in the same ‘name value’ format that handles_add_ids expects.

pub const name: String
Search Document