vxml_pipeline/desugarers/wrap_if_not_child_of
Values
pub fn assertive_tests() -> testing.AssertiveTestCollection
pub fn constructor(
param: #(String, String, List(String)),
) -> core.Desugarer
Wraps each occurrence of a target tag in a new parent tag, unless the target is a direct child of one of the specified excluded parent tags.